@@ -356,9 +356,19 @@ def workspace_item_image(request, workspace_item_id):
     identifier_json_list = request.GET.getlist('identifier')
     identifier_list = [simplejson.loads(json) for json in identifier_json_list]
 
-    width = request.GET.get('width', None)
-    height = request.GET.get('height', None)
-
+    width = request.GET.get('width')
+    height = request.GET.get('height')
+    if width:
+        width = int(width)
+    else:
+        # We want None, not u''.
+        width = None
+    if height:
+        height = int(height)
+    else:
+        # We want None, not u''.
+        height = None
+    print "%r, %r" % (width, height)
     workspace_item = get_object_or_404(WorkspaceItem, pk=workspace_item_id)
     start_date, end_date = current_start_end_dates(request)
     return workspace_item.adapter.image(identifier_list, start_date, end_date, width, height)
